@@ -19,8 +19,8 @@
 
 
 
-#ifndef __COMMON_H__
-#define __COMMON_H__
+#ifndef __CLASSAD_COMMON_H__
+#define __CLASSAD_COMMON_H__
 
 #ifndef WIN32
 #include <strings.h>
@@ -58,6 +58,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
+#include <limits.h>
 #include <math.h>
 #ifndef WIN32
 	#include <unistd.h>
@@ -66,9 +67,6 @@
 #include <errno.h>
 #include <ctype.h>
 
-#ifndef WORD_BIT
-#define WORD_BIT 32
-#endif
 
 
 
@@ -207,4 +205,4 @@ char* strnewp( const char* );
 
 #include "classad/classadErrno.h"
 
-#endif//__COMMON_H__
+#endif//__CLASSAD_COMMON_H__
